'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.detect = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.default = detect;
exports.detectSync = detectSync;

var _fileType = require('file-type');

var _fileType2 = _interopRequireDefault(_fileType);

var _common = require('@webex/common');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Determine mimeType for the specified buffer;
 * @param {Buffer} buffer
 * @returns {Promise<string>}
 */
/*!
 * Copyright (c) 2015-2019 Cisco Systems, Inc. See LICENSE file.
 */

function detect(buffer) {
  return new _promise2.default(function (resolve) {
    resolve(detectSync(buffer));
  });
}

exports.detect = detect;

/**
 * Synchronous implementation of {@link detect}
 * @param {Buffer} buffer
 * @returns {string}
 */

function detectSync(buffer) {
  /* global Blob */
  var b = buffer;

  if (_common.inBrowser) {
    if (buffer instanceof Blob) {
      return buffer.type;
    }
    if (buffer instanceof ArrayBuffer) {
      b = new Uint8Array(buffer);
    } else if (!(buffer instanceof Uint8Array)) {
      throw new Error('`detect` requires a buffer of type Blob, ArrayBuffer, or Uint8Array');
    }
  }

  var type = (0, _fileType2.default)(b);

  if (!type) {
    return 'application/octet-stream';
  }

  return type.mime;
}
//# sourceMappingURL=detect.js.map
