"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var ControlsUtils = {};

/**
 * Controls
 * @typedef {Object} LocusControls
 * @property {Object} record
 * @property {Boolean} record.recording
 * @property {Object} record.meta
 * @property {String} record.meta.modifiedBy
 */

/**
 * parse the relevant host values that we care about: id
 * @param {LocusControls} controls
 * @returns {Object} parsedObject - parsed host or null if host was undefined
 * @returns {String} parsedObject.recordingId
 */
ControlsUtils.parse = function (controls) {
  if (controls) {
    return {
      recordingId: ControlsUtils.getId(controls)
    };
  }

  return null;
};

/**
 * Extract the id from the record controls object
 * @param {LocusControls} controls
 * @returns {String|null}
 */
ControlsUtils.getId = function (controls) {
  if (!controls || !controls.record || !controls.record.recording) {
    return null;
  }
  if (controls.record && controls.record.meta && controls.record.recording) {
    return controls.record.meta.modifiedBy;
  }

  return null;
};

exports.default = ControlsUtils;
//# sourceMappingURL=controlsUtils.js.map
